package commonj.sdo.helper.util;

import javax.xml.transform.Result;

import commonj.sdo.helper.HelperContext;
import commonj.sdo.helper.XMLDocument;

/**
 * With this interface frameworks are able to create an SDO data graph as a
 * javax.xml.transform.Result.
 * The implementation of this class may extend javax.xml.transform.sax.SAXResult
 * or another well supported Result-implementation.
 * @see commonj.sdo.helper.XMLHelper#createSDOResult(Object)
 */
public interface SDOResult extends Result {

    /**
     * Returns the result XMLDocument after the SDOResult is completed.
     * @return The result XMLDocument.
     */
    XMLDocument getDocument();
    
    /**
     * Shortcut for SDO-aware frameworks to set the result XMLDocument.
     * @param document The result XMLDocument.
     */
    void setDocument(XMLDocument document);
    
    /**
     * Returns the HelperContext of this SDOResult. The result XMLDocument must
     * be created in this HelperContext.
     * @return The target HelperContext.
     */
    HelperContext getHelperContext();

}
